<?php

namespace App\Http\Controllers;

use Illuminate\Support\Facades\Validator;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use App\Models\HospitalGuarantee;
use App\Models\UserApp;
use App\Models\RSYkp;
use App\Models\Outstanding;
use App\Models\Plafond;
use Illuminate\Support\Facades\Mail;
use App\Mail\JaminanRs;
use Auth;

class HospitalGuaranteeController extends Controller
{
  
    public function __construct()
    { }
    public function index($id)
    {
        try {
          $data = HospitalGuarantee::where('user_id', $id)->select('id', 'name', 'status')->orderby('id', 'desc')->get();
          if($data->isEmpty()){
             return response()->json(['success' => false, 'message' => 'not_found'], 404); 
          }
          
                $messages = [
                    'code' => 200,
                    'message' => 'success',
                    'data'=> $data
                ];
        }catch (\Exception $e) {
                    $messages = [
                        'code' => 500,
                        'message' => $e->getMessage()
                    ];
        }
                return response()
                    ->json($messages, $messages['code'])
                    ->header('Content-Type', 'application/json');
    }
    public function detail($id)
    {
        try {
          $data = HospitalGuarantee::where('id', $id)->get()->map(function ($item) {
              $rs = RSYkp::find($item->hospital_id);
              $item['responses'] = json_decode($item->responses);
              $item['rs_title'] = $rs->title;
              $item['rs_phone'] = $rs->phone;
              $item['rs_address'] = $rs->address;
              $item['lampiran'] = 'https://backend.sipurna.com/surat-jaminan-'.$item->id;
              return $item;
          });
          if(!$data){
             return response()->json(['success' => false, 'message' => 'not_found'], 404); 
          }
          
                $messages = [
                    'code' => 200,
                    'message' => 'success',
                    'data'=> $data
                ];
        }catch (\Exception $e) {
                    $messages = [
                        'code' => 500,
                        'message' => $e->getMessage()
                    ];
        }
                return response()
                    ->json($messages, $messages['code'])
                    ->header('Content-Type', 'application/json');
    }
    public function createbu(Request $request)
    {
        // return response()->json(['code'=>404,'success' => false, 'message' => 'sedang dalam perbaikan, bisa dicoba dilain waktu'], 404);
        // return "asy";
        $validation = Validator::make($request->all(), [
          'user_id' => 'required',
          'name' => 'required|string',
          'nik' => 'required',
          'type' => 'required',
          'start_date' => 'required',
          'rs_id' => 'required', 
        ]);
    
        if ($validation->fails()) {
          return response()->json(['success' => false, 'message' => $validation->errors()->first()], 422);
        }
        
        try {
          $id = $request->user_id;
          $name = $request->name;
          $nik = $request->nik;
          $type = $request->type;
          $start_date = $request->start_date;
          $disease = $request->disease;
          $rs = $request->rs_id;
          
          $user = UserApp::find($id);
          $drs = RSYkp::find($rs);
          $out = Outstanding::where('npp', $user->npp)->orderby('id', 'desc')->first();
          $pla = Plafond::where('npp', $user->npp)->where('type', 1)->orderby('id', 'desc')->first();
          $p_date = explode('-', $out->position_date);
          
          $reqs = array(
                    "nama_pasien" => $name,
                    "hub_keluarga" => $type,
                    "nik_pasien" => $nik,
                    "kode_rs" => $rs,
                    "nama_rs" => $drs->title,
                    "alamat_rs" => $drs->address,
                    "telepon" => $drs->phone,
                    "tgl_dirawat" => $start_date,
                    "nama_penyakit" => $disease
              );
        $params = array(
                    "npp" => $user->npp,
                    "type" => $pla->type,
                    "bulan" => (int) $p_date['1'],
                    "tahun" => $p_date['0'],
                    "kelas" =>  $user->type_class
              );
        //   $reqs = array(
        //             "nama_pasien" => "DEANDRA HAKAN NAFIS",
        //             "hub_keluarga" => "anak",
        //             "nik_pasien" => "----",
        //             "kode_rs" => 184,
        //             "nama_rs" => "UJI COBA RUMAH SAKIT - 2",
        //             "alamat_rs" => "JAKARTA",
        //             "telepon" => "999999999999999",
        //             "tgl_dirawat" => "2020-02-02",
        //             "nama_penyakit" => "Test"
        //       );
        //   $params = array(
        //             "npp" => "15722",
        //             "type" => "1",
        //             "bulan" => 10,
        //             "tahun" => "2021",
        //             "kelas" =>  " II "
        //       );
        // return $params;
          $hitJRS = HospitalGuarantee::hitSJaminanRs($reqs, $params);
          if(empty($hitJRS)){
              return response()->json(['code'=>500,'success' => false, 'message' => 'empty response rijal'], 500);  
             
          }
        // return $hitJRS;
          $status = $hitJRS['code'];
          $message = $hitJRS['message'];
          
          
          
          $romawi = HospitalGuarantee::getRomawi(date("n"));
          $year = date("Y");
          $cek = HospitalGuarantee::orderby('id', 'desc')->first();
          if(!$cek){
              $no = 1;
          }else{
              
            $code = explode("/", $cek->code);
            // return $code[4];
              if($code[5] <> $year){
                  $no = 1;
              }else{
                  $no = $code['0'] + 1;    
              }
              
          }
          $code = $no."/"."YKP-BTN/KSJ/SIPURNA/".$romawi."/".$year;
          
          
          if($status <> "200"){
              return response()->json(['code'=>404,'success' => false, 'message' => $message], $status);  
             
          }
              $email_rs = $hitJRS['email_rs']['0']['email'];
              $email_pengda = $hitJRS['email_pengda']['0']['email'];
              $token = substr(str_shuffle(str_repeat("ABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789", 6)), 0, 6);
              $responses = array(
                        "data" => $hitJRS['data'],
                        "tarif" => $hitJRS['tarif']
                  );
              $create = new HospitalGuarantee;
              $create->code = $code;
              $create->user_id = $id;
              $create->name = $name;
              $create->nik = $nik;
              $create->type = $type;
              $create->start_date = $start_date;
              $create->disease = $disease;
              $create->hospital_id = $rs;
              $create->responses = json_encode($responses);
              $create->verified_code = Hash::make($token);
              $create->status = 'pending';
              $create->save();
              
                $datas = $create->toArray();
                $toks = array(
                    'token' => $token,
                    'nama' => $user->fullname,
                    'email' => $user->email,
                    );
                $data = array_merge($datas, $toks);
                if($email_rs != ''){
                // SEND EMAIL RS
                Mail::send('email.jaminanrsrs', $data, function($message) use($data, $email_rs) {
        
                // $message->to($email_rs, 'YKP Bank BTN')->subject('Form Jaminan RS YKP-BTN');
                $message->to('ferdiansyah071@gmail.com', 'YKP Bank BTN')->subject('Form Jaminan RS YKP-BTN');
                $message->from('pengelola@sipurna.com', 'Pengelola Sipurna');
                // foreach($files as $file){
                //     $url = str_replace('https://sipurna.com/', '', $file);
                //     $message->attach(base_path(env('PATH_WEB').$url));
                // }
        
                });
                }
                // SEND EMAIL YKP
                Mail::send('email.jaminanrsykp', $data, function($message) use($data) {
        
                // $message->to('ykpbtn@yahoo.com', 'YKP Bank BTN')->subject('Form Jaminan RS YKP-BTN');
                $message->to('ferdiansyah071@gmail.com', 'YKP Bank BTN')->subject('Form Jaminan RS YKP-BTN');
                $message->from('pengelola@sipurna.com', 'Pengelola Sipurna');
                // foreach($files as $file){
                //     $url = str_replace('https://sipurna.com/', '', $file);
                //     $message->attach(base_path(env('PATH_WEB').$url));
                // }
        
                });
                
                if($email_pengda != ''){
                // SEND EMAIL PENGDA
                Mail::send('email.jaminanrspengda', $data, function($message) use($data, $email_pengda) {
        
                // $message->to($email_pengda, 'YKP Bank BTN')->subject('Form Jaminan RS YKP-BTN');
                $message->to('ferdiansyah071@gmail.com', 'YKP Bank BTN')->subject('Form Jaminan RS YKP-BTN');
                $message->from('pengelola@sipurna.com', 'Pengelola Sipurna');
                // foreach($files as $file){
                //     $url = str_replace('https://sipurna.com/', '', $file);
                //     $message->attach(base_path(env('PATH_WEB').$url));
                // }
        
                });
                }
                $messages = [
                    'code' => 201,
                    'message' => 'success',
                    'token'=> $token,
                    'data'=> $create
                ];
        }catch (\Exception $e) {
                    $messages = [
                        'code' => 500,
                        'message' => $e->getMessage()
                        // 'message' => 'Mohon maaf sedang ada kendala, silahkan hubungi Admin...'
                    ];
        }
                return response()
                    ->json($messages, $messages['code'])
                    ->header('Content-Type', 'application/json');
    }
    public function create(Request $request)
    {
        
        $validation = Validator::make($request->all(), [
          'user_id' => 'required',
          'name' => 'required|string',
          'nik' => 'required',
          'type' => 'required',
          'start_date' => 'required',
          'rs_id' => 'required', 
        ]);
    
        if ($validation->fails()) {
          return response()->json(['success' => false, 'message' => $validation->errors()->first()], 422);
        }
        
        try {
          $id = $request->user_id;
          $name = $request->name;
          $nik = $request->nik;
          $type = $request->type;
          $start_date = $request->start_date;
          $disease = $request->disease;
          $rs = $request->rs_id;
          
          $user = UserApp::find($id);
          $drs = RSYkp::find($rs);
          $out = Outstanding::where('npp', $user->npp)->orderby('id', 'desc')->first();
          $pla = Plafond::where('npp', $user->npp)->where('type', 1)->orderby('id', 'desc')->first();
          $p_date = explode('-', $out->position_date);
          
          $reqs = array(
                    "nama_pasien" => $name,
                    "hub_keluarga" => $type,
                    "nik_pasien" => $nik,
                    "kode_rs" => $rs,
                    "nama_rs" => $drs->title,
                    "alamat_rs" => $drs->address,
                    "telepon" => $drs->phone,
                    "tgl_dirawat" => $start_date,
                    "nama_penyakit" => $disease
              );
        $params = array(
                    "npp" => $user->npp,
                    "type" => $pla->type,
                    "bulan" => (int) $p_date['1'],
                    "tahun" => $p_date['0'],
                    "kelas" =>  $user->type_class
              );
        
          $hitJRS = HospitalGuarantee::hitSJaminanRs($reqs, $params);
          if(empty($hitJRS)){
              return response()->json(['code'=>500,'success' => false, 'message' => 'empty response rijal'], 500);  
             
          }
          $status = $hitJRS['code'];
          $message = $hitJRS['message'];
          
          
          
          $romawi = HospitalGuarantee::getRomawi(date("n"));
          $year = date("Y");
          $cek = HospitalGuarantee::orderby('id', 'desc')->first();
          if(!$cek){
              $no = 1;
          }else{
              
            $code = explode("/", $cek->code);
        
              if($code[5] <> $year){
                  $no = 1;
              }else{
                  $no = $code['0'] + 1;    
              }
              
          }
          $code = $no."/"."YKP-BTN/KSJ/SIPURNA/".$romawi."/".$year;
          
          
          if($status <> "200"){
              return response()->json(['code'=>404,'success' => false, 'message' => $message], $status);  
             
          }
              $email_rs = $hitJRS['email_rs']['0']['email'];
              $email_pengda = $hitJRS['email_pengda']['0']['email'];
              $token = substr(str_shuffle(str_repeat("ABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789", 6)), 0, 6);
              $responses = array(
                        "data" => $hitJRS['data'],
                        "tarif" => $hitJRS['tarif']
                  );
              $create = new HospitalGuarantee;
              $create->code = $code;
              $create->user_id = $id;
              $create->name = $name;
              $create->nik = $nik;
              $create->type = $type;
              $create->start_date = $start_date;
              $create->disease = $disease;
              $create->hospital_id = $rs;
              $create->responses = json_encode($responses);
              $create->verified_code = Hash::make($token);
              $create->status = 'pending';
              $create->save();
              
                $datas = $create->toArray();
                $toks = array(
                    'token' => $token,
                    'nama' => $user->fullname,
                    'email' => $user->email,
                    );
                $data = array_merge($datas, $toks);
                $email = Mail::to('muhamadaderohayat122@gmail.com')->send(new JaminanRs($data));
                if(count(Mail::failures()) > 0){
    return 'Failed to send password reset email, please try again.';
}
                return $email;
                $messages = [
                    'code' => 201,
                    'message' => 'success',
                    'token'=> $token,
                    'data'=> $create,
                    'email'=>$email
                ];
        }catch (\Exception $e) {
                    $messages = [
                        'code' => 500,
                        'message' => $e->getMessage()
                        // 'message' => 'Mohon maaf sedang ada kendala, silahkan hubungi Admin...'
                    ];
        }
                return response()
                    ->json($messages, $messages['code'])
                    ->header('Content-Type', 'application/json');
    }
    public function confirm(Request $request)
    {
        $validation = Validator::make($request->all(), [
          'id' => 'required',
          'code' => 'required'
        ]);
    
        if ($validation->fails()) {
          return response()->json(['success' => false, 'message' => $validation->errors()->first()], 422);
        }
        
        try {
          $id = $request->id;
          $hos = HospitalGuarantee::find($id);
          
          $code = $request->code;
          
          $user = UserApp::find($hos->user_id);
          if (!$user) {
            return response()->json(['success' => false, 'message' => 'user_not_found'], 404);
          }
          
           if (Hash::check($code, $hos->verified_code)) {
               $update = $hos;
               $update->status = 'verified';
               $update->verified_at = date("Y-m-d H:i:s");
               $update->save();
           }else{
               return response()->json(['success' => false, 'message' => 'not_match'], 400);
           }
          
                $messages = [
                    'code' => 200,
                    'message' => 'match'
                ];
        }catch (\Exception $e) {
                    $messages = [
                        'code' => 500,
                        'message' => $e->getMessage()
                    ];
        }
                return response()
                    ->json($messages, $messages['code'])
                    ->header('Content-Type', 'application/json');
        }
    
     
}