<?php

namespace App\Http\Controllers;

use App\Models\Notification; 
use App\Models\NotificationRead; 
use App\Http\Resources\NotificationResource;
use Illuminate\Support\Facades\Validator;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Auth;

class NotificationController extends Controller
{
    public function __construct()
    { }

    public function index($id)
    {
        $data = Notification::addSelect(['is_read' => NotificationRead::select(DB::raw('COUNT(id)'))
                                        ->whereColumn('notification_read.notification_id', 'notification.id')
                                        ->where('notification_read.user_id', $id)
                                        ->limit(1)
                                        ])
                            ->addSelect(['notif_read_id' => NotificationRead::select('id')
                                        ->whereColumn('notification_read.notification_id', 'notification.id')
                                        ->where('notification_read.user_id', $id)
                                        ->limit(1)
                                        ])
                             ->addSelect(['status' => NotificationRead::select('status')
                                        ->whereColumn('notification_read.notification_id', 'notification.id')
                                        ->where('notification_read.user_id', $id)
                                        ->limit(1)
                                        ])
                            ->get();
        
        try {
            if($data->isEmpty()){
                $messages = [
                    'code' => 400,
                    'message' => 'Tidak Ada Data'
                ];
            }else{
                $messages = [
                    'code' => 200,
                    'message' => 'Berhasil Menampilkan Data',
                    'data' =>  $data
                ];
            }
        }catch (\Exception $e) {
                    $messages = [
                        'code' => 500,
                        'message' => $e->getMessage()
                    ];
        }
                return response()
                    ->json($messages, $messages['code'])
                    ->header('Content-Type', 'application/json');
    }
    public function get($id)
    {
        $data = Notification::find($id);
        
        try {
            if(!$data){
                $messages = [
                    'code' => 400,
                    'message' => 'Tidak Ada Data'
                ];
            }else{
                $messages = [
                    'code' => 200,
                    'message' => 'Berhasil Menampilkan Data',
                    'data' =>  $data
                ];
            }
        }catch (\Exception $e) {
                    $messages = [
                        'code' => 500,
                        'message' => $e->getMessage()
                    ];
        }
                return response()
                    ->json($messages, $messages['code'])
                    ->header('Content-Type', 'application/json');
    }
    public function read(Request $request, NotificationRead $notif)
    {
        $this->validate($request, [
            'user_id'             => 'required',
            'notification_id'     => 'required',
        ]);
        
        $ceknotif = $notif->where('user_id',$request->user_id)
                         ->where('notification_id', $request->notification_id);
        if($ceknotif->count() == 0){
        $notif = $notif->create([
            'user_id'             => $request->user_id,
            'notification_id'             => $request->notification_id,
            'created_at'         => date('Y-m-d H:i:s')
        ]);
        }

        return response()->json([
            'status_code' => 201,
            'success' => true,
            'message' => 'Berhasil Menambah'
        ], 201);
    }
    public function del_notif($notif_read_id)
    {
        
        $notif = NotificationRead::where('id',$notif_read_id);
        $notif = $notif->update([
            'status'             => "deleted"
        ]);
        

        return response()->json([
            'status_code' => 201,
            'success' => true,
            'message' => 'Berhasil Menghapus Notif'
        ], 201);
    }
    public function del_notif_all($user_id)
    {
        
        $notif = NotificationRead::where('user_id',$user_id);
        $notif = $notif->update([
            'status'             => "deleted"
        ]);
        

        return response()->json([
            'status_code' => 201,
            'success' => true,
            'message' => 'Berhasil Menghapus Notif'
        ], 201);
    }
    function sendMessage($content){
        $content = array(
            "en" => $content
            );
        
    
        $fields = array(
            'app_id' => "c2e8bee4-b807-48b9-985c-ea1d496dffee",
            'include_external_user_ids' => array('45'),
            'channel_for_external_user_ids' => 'push',
            'data' => array("foo" => "bar"),
            'contents' => $content
        );
        
        $fields = json_encode($fields);
        
        
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, "https://onesignal.com/api/v1/notifications");
        curl_setopt($ch, CURLOPT_HTTPHEADER, array('Content-Type: application/json; charset=utf-8',
                                                   'Authorization: Basic MjA4MzhlYzAtOGJlYS00OWRmLWI2MmQtYTI5ZDU5ODFhOGE4'));
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, TRUE);
        curl_setopt($ch, CURLOPT_HEADER, FALSE);
        curl_setopt($ch, CURLOPT_POST, TRUE);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $fields);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, FALSE);

        $response = curl_exec($ch);
        curl_close($ch);
        return response()->json([
            'status_code' => 200,
            'success' => true,
            'message' => "Berhasil Kirim",
        ], 200);
 

        // $response = sendMessage();
        // $return["allresponses"] = $response;
        // $return = json_encode( $return);
    }
}
